==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicyRuleFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EgressNetworkPolicyRuleFluent<A extends EgressNetworkPolicyRuleFluent<A>> extends BaseFluent<A>{
  public EgressNetworkPolicyRuleFluent() {
  }
  
  public EgressNetworkPolicyRuleFluent(EgressNetworkPolicyRule instance) {
    this.copyInstance(instance);
  }
  private EgressNetworkPolicyPeerBuilder to;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(EgressNetworkPolicyRule instance) {
    instance = (instance != null ? instance : new EgressNetworkPolicyRule());
  
    if (instance != null) {
        this.withTo(instance.getTo());
        this.withType(instance.getType());
        this.withTo(instance.getTo());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public EgressNetworkPolicyPeer buildTo() {
    return this.to!=null ?this.to.build():null;
  }
  
  public A withTo(EgressNetworkPolicyPeer to) {
    _visitables.get("to").remove(this.to);
    if (to!=null){ this.to= new EgressNetworkPolicyPeerBuilder(to); _visitables.get("to").add(this.to);} else { this.to = null; _visitables.get("to").remove(this.to); } return (A) this;
  }
  
  public boolean hasTo() {
    return this.to != null;
  }
  
  public A withNewTo(String cidrSelector,String dnsName) {
    return (A)withTo(new EgressNetworkPolicyPeer(cidrSelector, dnsName));
  }
  
  public ToNested<A> withNewTo() {
    return new ToNested(null);
  }
  
  public ToNested<A> withNewToLike(EgressNetworkPolicyPeer item) {
    return new ToNested(item);
  }
  
  public ToNested<A> editTo() {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(null));
  }
  
  public ToNested<A> editOrNewTo() {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(new EgressNetworkPolicyPeerBuilder().build()));
  }
  
  public ToNested<A> editOrNewToLike(EgressNetworkPolicyPeer item) {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EgressNetworkPolicyRuleFluent that = (EgressNetworkPolicyRuleFluent) o;
    if (!java.util.Objects.equals(to, that.to)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(to,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (to != null) { sb.append("to:"); sb.append(to + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ToNested<N> extends EgressNetworkPolicyPeerFluent<ToNested<N>> implements Nested<N>{
    ToNested(EgressNetworkPolicyPeer item) {
      this.builder = new EgressNetworkPolicyPeerBuilder(this, item);
    }
    EgressNetworkPolicyPeerBuilder builder;
    
    public N and() {
      return (N) EgressNetworkPolicyRuleFluent.this.withTo(builder.build());
    }
    
    public N endTo() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/EgressNetworkPolicyRuleFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EgressNetworkPolicyRuleFluent<A extends EgressNetworkPolicyRuleFluent<A>> extends BaseFluent<A>{
  public EgressNetworkPolicyRuleFluent() {
  }
  
  public EgressNetworkPolicyRuleFluent(EgressNetworkPolicyRule instance) {
    this.copyInstance(instance);
  }
  private EgressNetworkPolicyPeerBuilder to;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(EgressNetworkPolicyRule instance) {
    instance = (instance != null ? instance : new EgressNetworkPolicyRule());
    if (instance != null) {
          this.withTo(instance.getTo());
          this.withType(instance.getType());
          this.withTo(instance.getTo());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public EgressNetworkPolicyPeer buildTo() {
    return this.to != null ? this.to.build() : null;
  }
  
  public A withTo(EgressNetworkPolicyPeer to) {
    this._visitables.remove(this.to);
    if (to != null) {
        this.to = new EgressNetworkPolicyPeerBuilder(to);
        this._visitables.get("to").add(this.to);
    } else {
        this.to = null;
        this._visitables.get("to").remove(this.to);
    }
    return (A) this;
  }
  
  public boolean hasTo() {
    return this.to != null;
  }
  
  public A withNewTo(String cidrSelector,String dnsName) {
    return (A)withTo(new EgressNetworkPolicyPeer(cidrSelector, dnsName));
  }
  
  public ToNested<A> withNewTo() {
    return new ToNested(null);
  }
  
  public ToNested<A> withNewToLike(EgressNetworkPolicyPeer item) {
    return new ToNested(item);
  }
  
  public ToNested<A> editTo() {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(null));
  }
  
  public ToNested<A> editOrNewTo() {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(new EgressNetworkPolicyPeerBuilder().build()));
  }
  
  public ToNested<A> editOrNewToLike(EgressNetworkPolicyPeer item) {
    return withNewToLike(java.util.Optional.ofNullable(buildTo()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EgressNetworkPolicyRuleFluent that = (EgressNetworkPolicyRuleFluent) o;
    if (!java.util.Objects.equals(to, that.to)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(to,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (to != null) { sb.append("to:"); sb.append(to + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ToNested<N> extends EgressNetworkPolicyPeerFluent<ToNested<N>> implements Nested<N>{
    ToNested(EgressNetworkPolicyPeer item) {
      this.builder = new EgressNetworkPolicyPeerBuilder(this, item);
    }
    EgressNetworkPolicyPeerBuilder builder;
    
    public N and() {
      return (N) EgressNetworkPolicyRuleFluent.this.withTo(builder.build());
    }
    
    public N endTo() {
      return and();
    }
    
  
  }

}
